@@ -17,8 +17,12 @@ from typing import (
 )
 from functools import update_wrapper
 from collections import OrderedDict
+import sys
 
-from typing_extensions import Protocol, TypedDict
+if sys.version_info[:2] >= (3, 8):
+    from typing import Protocol, TypedDict
+else:
+    from typing_extensions import Protocol, TypedDict
 
 from ._utility import public_module
 
